aboutsummaryrefslogtreecommitdiffstats
path: root/rjit_c.rb
diff options
context:
space:
mode:
Diffstat (limited to 'rjit_c.rb')
-rw-r--r--rjit_c.rb16
1 files changed, 8 insertions, 8 deletions
diff --git a/rjit_c.rb b/rjit_c.rb
index d670a6582a..a0e1d1f8d9 100644
--- a/rjit_c.rb
+++ b/rjit_c.rb
@@ -1,7 +1,7 @@
# frozen_string_literal: true
# Part of this file is generated by tool/mjit/bindgen.rb.
-# Run `make mjit-bindgen` to update code between "MJIT bindgen begin" and "MJIT bindgen end".
-module RubyVM::MJIT # :nodoc: all
+# Run `make mjit-bindgen` to update code between "RJIT bindgen begin" and "RJIT bindgen end".
+module RubyVM::RJIT # :nodoc: all
# This `class << C` section is for calling C functions. For importing variables
# or macros as is, please consider using tool/mjit/bindgen.rb instead.
class << C = Object.new
@@ -12,7 +12,7 @@ module RubyVM::MJIT # :nodoc: all
def mjit_mark_writable
Primitive.cstmt! %{
extern bool rb_yjit_mark_writable(void *mem_block, uint32_t mem_size);
- rb_yjit_mark_writable(rb_mjit_mem_block, MJIT_CODE_SIZE);
+ rb_yjit_mark_writable(rb_mjit_mem_block, RJIT_CODE_SIZE);
return Qnil;
}
end
@@ -20,14 +20,14 @@ module RubyVM::MJIT # :nodoc: all
def mjit_mark_executable
Primitive.cstmt! %{
extern bool rb_yjit_mark_executable(void *mem_block, uint32_t mem_size);
- rb_yjit_mark_executable(rb_mjit_mem_block, MJIT_CODE_SIZE);
+ rb_yjit_mark_executable(rb_mjit_mem_block, RJIT_CODE_SIZE);
return Qnil;
}
end
def mjit_insn_exits
addr = Primitive.cstmt! %{
- #if MJIT_STATS
+ #if RJIT_STATS
return SIZET2NUM((size_t)mjit_insn_exits);
#else
return SIZET2NUM(0);
@@ -45,7 +45,7 @@ module RubyVM::MJIT # :nodoc: all
def rb_mjit_counters
addr = Primitive.cstmt! %{
- #if MJIT_STATS
+ #if RJIT_STATS
return SIZET2NUM((size_t)&rb_mjit_counters);
#else
return SIZET2NUM(0);
@@ -569,7 +569,7 @@ module RubyVM::MJIT # :nodoc: all
end
end
### MJIT bindgen begin ###
def C.USE_LAZY_LOAD
Primitive.cexpr! %q{ RBOOL(USE_LAZY_LOAD != 0) }
@@ -1872,5 +1872,5 @@ module RubyVM::MJIT # :nodoc: all
CType::Stub.new(:rb_ext_config)
end
### MJIT bindgen end ###
end if Primitive.mjit_enabled_p
@@ -569,7 +569,7 @@ module RubyVM::MJIT # :nodoc: all
end
end
- ### MJIT bindgen begin ###
+ ### RJIT bindgen begin ###
def C.USE_LAZY_LOAD
Primitive.cexpr! %q{ RBOOL(USE_LAZY_LOAD != 0) }
@@ -1872,5 +1872,5 @@ module RubyVM::MJIT # :nodoc: all
CType::Stub.new(:rb_ext_config)
end
- ### MJIT bindgen end ###
+ ### RJIT bindgen end ###
end if Primitive.mjit_enabled_p